"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RabbitMQMessageBus_1 = require("./messageBus/RabbitMQMessageBus");
const DEFAULT_RETRY_DELAY_TIME = 60;
var BrokerType;
(function (BrokerType) {
    BrokerType["RABBITMQ"] = "RABBITMQ";
})(BrokerType = exports.BrokerType || (exports.BrokerType = {}));
class Mercury {
    constructor(brokerType, brokerHostName, brokerUserName, brokerPassword, appName, serviceName, retryDelayTime = DEFAULT_RETRY_DELAY_TIME, filterMessages = true, preFetch = 2) {
        this.appName = appName;
        this.serviceName = serviceName;
        this.brokerHostName = brokerHostName;
        this.brokerUserName = brokerUserName;
        this.brokerPassword = brokerPassword;
        this.retryDelayTime = retryDelayTime;
        this.filterMessages = filterMessages;
        this.preFetch = preFetch;
    }
    setMessageBus(brokerType = BrokerType.RABBITMQ) {
        if (!this.container)
            throw Error('container not instantiated.');
        switch (brokerType) {
            case BrokerType.RABBITMQ:
                this.messageBus = new RabbitMQMessageBus_1.RabbitMQMessageBus(this.container);
                break;
            default:
                this.messageBus = new RabbitMQMessageBus_1.RabbitMQMessageBus(this.container);
                break;
        }
    }
    async init() {
        try {
            this.setMessageBus();
            return await this.messageBus.configure({
                appName: this.appName,
                brokerHostName: this.brokerHostName,
                brokerPassword: this.brokerPassword,
                brokerUserName: this.brokerUserName,
                filterMessages: this.filterMessages,
                retryDelay: this.retryDelayTime,
                serviceName: this.serviceName,
                preFetch: this.preFetch,
            });
        }
        catch (e) {
            throw e;
        }
    }
    useHandler(handler) {
        Mercury.handlerRegistry.set(handler.constructor.name, handler);
    }
    setContainer(container) {
        this.container = container;
    }
    async terminate() {
        return await this.messageBus.terminate();
    }
}
exports.Mercury = Mercury;
Mercury.handlerRegistry = new Map();
//# sourceMappingURL=Mercury.js.map